# xaudio

[![Documentation Status](https://readthedocs.org/projects/xaudio/badge/?version=latest)](https://xaudio.readthedocs.io/en/latest/?badge=latest)
[![PyPI version](https://badge.fury.io/py/xaudio.svg)](https://pypi.org/project/xaudio/)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](LICENSE)
[![Python Version](https://img.shields.io/pypi/pyversions/xaudio.svg)](https://pypi.org/project/xaudio/)
[![Unit-tests](https://github.com/int2code/xaudio/actions/workflows/unit_tests.yml/badge.svg?branch=main)](https://github.com/int2code/xaudio/actions/workflows/unit_tests.yml)
[![Publish Python Package](https://github.com/int2code/xaudio/actions/workflows/publish_to_pypi.yml/badge.svg)](https://github.com/int2code/xaudio/actions/workflows/publish_to_pypi.yml)

This package provides classes used to communicate with `XAudio` device over different, 
supported mediums and protocols.